@@ -1,6 +1,6 @@
 __version__ = "0.2.14"
 
-#  Copyright 2023 Synnax Labs, Inc.
+#  Copyright 2025 Synnax Labs, Inc.
 #
 #  Use of this software is governed by the Business Source License included in the file
 #  licenses/BSL.txt.
@@ -13,8 +13,8 @@ from freighter.alamos import (
     async_instrumentation_middleware,
     instrumentation_middleware,
 )
+from freighter.codec import Codec, JSONCodec, MsgPackCodec
 from freighter.context import Context, Role
-from freighter.encoder import EncoderDecoder, JSONEncoder, MsgpackEncoder
 from freighter.exceptions import (
     EOF,
     ExceptionPayload,
@@ -25,11 +25,11 @@ from freighter.exceptions import (
 )
 from freighter.http import HTTPClient
 from freighter.stream import AsyncStream, AsyncStreamClient, Stream, StreamClient
-from freighter.sync import SyncStreamClient
 from freighter.transport import (
     AsyncFinalizer,
     AsyncMiddleware,
     AsyncNext,
+    Empty,
     Finalizer,
     Middleware,
     MiddlewareCollector,
@@ -37,6 +37,43 @@ from freighter.transport import (
     Payload,
     Transport,
 )
-from freighter.unary import UnaryClient
+from freighter.unary import AsyncUnaryClient, UnaryClient, send_required
 from freighter.url import URL
-from freighter.websocket import WebsocketClient
+from freighter.websocket import AsyncWebsocketClient, WebsocketClient
+
+__all__ = [
+    "AsyncFinalizer",
+    "AsyncMiddleware",
+    "AsyncNext",
+    "AsyncStream",
+    "AsyncStreamClient",
+    "AsyncUnaryClient",
+    "AsyncWebsocketClient",
+    "AsyncWebsocketStream",
+    "async_instrumentation_middleware",
+    "Codec",
+    "Context",
+    "decode_exception",
+    "encode_exception",
+    "EOF",
+    "Empty",
+    "ExceptionPayload",
+    "Finalizer",
+    "HTTPClient",
+    "instrumentation_middleware",
+    "JSONCodec",
+    "Middleware",
+    "MiddlewareCollector",
+    "MsgPackCodec",
+    "Next",
+    "Payload",
+    "register_exception",
+    "send_required",
+    "Stream",
+    "StreamClient",
+    "StreamClosed",
+    "Transport",
+    "UnaryClient",
+    "URL",
+    "WebsocketClient",
+]
